<?php

namespace Anyone\Onlyone\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Anyone\Onlyone\Http\Requests\MasterRequest;
use Anyone\Onlyone\Models\Master;

/**
 * Admin web controller class.
 */
class MasterWorkflowController extends BaseController
{

    /**
     * Workflow controller function for master.
     *
     * @param Model   $master
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(MasterRequest $request, Master $master, $step)
    {

        try {

            $master->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('onlyone::master.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/master/master/' . $master->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/master/master/' . $master->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for master.
     *
     * @param Model   $master
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Master $master, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $master->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('onlyone::master.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('onlyone::admin.master.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('onlyone::admin.master.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('onlyone::admin.master.message', $data)->render();

        }

    }
}
