<?php

namespace Anyone\Onlyone\Providers;

use Illuminate\Support\ServiceProvider;

class OnlyoneServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'onlyone');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'onlyone');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('anyone.onlyone', function ($app) {
            return $this->app->make('Anyone\Onlyone\Onlyone');
        });

                // Bind Master to repository
        $this->app->bind(
            'Anyone\Onlyone\Interfaces\MasterRepositoryInterface',
            \Anyone\Onlyone\Repositories\Eloquent\MasterRepository::class
        );

        $this->app->register(\Anyone\Onlyone\Providers\AuthServiceProvider::class);
                $this->app->register(\Anyone\Onlyone\Providers\EventServiceProvider::class);
        
        $this->app->register(\Anyone\Onlyone\Providers\RouteServiceProvider::class);
                $this->app->register(\Anyone\Onlyone\Providers\WorkflowServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['anyone.onlyone'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('anyone/onlyone.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/onlyone')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/onlyone')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
