<?php

namespace Anyone\Onlyone\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Anyone\Onlyone\Models\Master;

class MasterAction
{
    /**
     * Perform the complete action.
     *
     * @param Master $master
     *
     * @return Master
     */
    public function complete(Master $master)
    {
        try {
            $master->status = 'complete';
            return $master->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Master $master
     *
     * @return Master
     */public function verify(Master $master)
    {
        try {
            $master->status = 'verify';
            return $master->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Master $master
     *
     * @return Master
     */public function approve(Master $master)
    {
        try {
            $master->status = 'approve';
            return $master->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Master $master
     *
     * @return Master
     */public function publish(Master $master)
    {
        try {
            $master->status = 'publish';
            return $master->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Master $master
     *
     * @return Master
     */
    public function archive(Master $master)
    {
        try {
            $master->status = 'archive';
            return $master->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Master $master
     *
     * @return Master
     */
    public function unpublish(Master $master)
    {
        try {
            $master->status = 'unpublish';
            return $master->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
