<?php

namespace Anyone\Onlyone\Workflow;

use Anyone\Onlyone\Models\Master;
use Validator;

class MasterValidator
{

    /**
     * Determine if the given master is valid for complete status.
     *
     * @param Master $master
     *
     * @return bool / Validator
     */
    public function complete(Master $master)
    {
        return Validator::make($master->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given master is valid for verify status.
     *
     * @param Master $master
     *
     * @return bool / Validator
     */
    public function verify(Master $master)
    {
        return Validator::make($master->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given master is valid for approve status.
     *
     * @param Master $master
     *
     * @return bool / Validator
     */
    public function approve(Master $master)
    {
        return Validator::make($master->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given master is valid for publish status.
     *
     * @param Master $master
     *
     * @return bool / Validator
     */
    public function publish(Master $master)
    {
        return Validator::make($master->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given master is valid for archive status.
     *
     * @param Master $master
     *
     * @return bool / Validator
     */
    public function archive(Master $master)
    {
        return Validator::make($master->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given master is valid for unpublish status.
     *
     * @param Master $master
     *
     * @return bool / Validator
     */
    public function unpublish(Master $master)
    {
        return Validator::make($master->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
